@@ -196,6 +196,13 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        patientPortal: {
+          description:
+            'Enable patient portal. When turned off, the patient portal api is disconnected and the UI in tamanu web to register portal users and assign them forms is hidden',
+          type: yup.boolean(),
+          defaultValue: false,
+          highRisk: true,
+        },
         onlyAllowLabPanels: {
           description: 'Only allow lab tests to be created via panels and not individual tests',
           type: yup.boolean(),
@@ -339,6 +346,16 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        deviceRegistrationQuota: {
+          description: 'Device registration quota settings',
+          properties: {
+            enabled: {
+              description: 'Enable device registration quota',
+              type: yup.boolean(),
+              defaultValue: true,
+            },
+          },
+        },
       },
     },
     customisations: {
@@ -946,7 +963,8 @@ export const globalSettings = {
       },
     },
     fileChooserMbSizeLimit: {
-      description: 'The maximum size in megabytes of files that can be uploaded with the file chooser',
+      description:
+        'The maximum size in megabytes of files that can be uploaded with the file chooser',
       type: yup.number().min(1),
       defaultValue: 10,
     },
@@ -1218,6 +1236,62 @@ export const globalSettings = {
     templates: {
       description: 'Strings to be inserted into emails/PDFs',
       properties: {
+        patientPortalLoginEmail: {
+          description: 'The email sent to the patient with their login code',
+          properties: {
+            subject: {
+              type: yup.string().trim().min(1),
+              defaultValue: 'Your Tamanu Patient Portal Login Code',
+            },
+            body: {
+              type: yup.string().trim().min(1),
+              defaultValue:
+                'Your 6-digit login code for Tamanu Patient Portal is: $token$\n\nDo not respond to this email.',
+            },
+          },
+        },
+        patientPortalRegistrationEmail: {
+          description: 'The email sent to the patient to register for the patient portal',
+          properties: {
+            subject: {
+              type: yup.string().trim().min(1),
+              defaultValue: 'Tamanu Patient Portal Registration',
+            },
+            body: {
+              type: yup.string().trim().min(1),
+              defaultValue:
+                'Please follow the link below to complete Tamanu Patient Portal registration for $firstName$ $lastName$.\n\n$registrationLink$\n\nDo not respond to this email',
+            },
+          },
+        },
+        patientPortalRegisteredFormEmail: {
+          description: 'The email sent to a registered patient to complete a form',
+          properties: {
+            subject: {
+              type: yup.string().trim().min(1),
+              defaultValue: 'New Patient Form Request from $facilityName$',
+            },
+            body: {
+              type: yup.string().trim().min(1),
+              defaultValue:
+                'A new patient form request has been sent from $facilityName$ for $firstName$ $lastName$. Please follow the below link to log in to your Tamanu Patient Portal to access and complete this form.\n\n$loginLink$\n\nYour 6-digit login code is: $loginCode$\n\nDo not respond to this email.',
+            },
+          },
+        },
+        patientPortalUnregisteredFormEmail: {
+          description: 'The email sent to an unregistered patient to complete a form',
+          properties: {
+            subject: {
+              type: yup.string().trim().min(1),
+              defaultValue: 'New Patient Form Request from $facilityName$',
+            },
+            body: {
+              type: yup.string().trim().min(1),
+              defaultValue:
+                'A new patient form request has been sent from $facilityName$ for $firstName$ $lastName$. Before you can access this form, you must register for a Tamanu Patient Portal account.\n\nPlease follow the link below to complete Tamanu Patient Portal registration for $firstName$ $lastName$. Once you have set up your patient portal account, you will be able to log in and access the requested form.\n\n$registrationLink$\n\nDo not respond to this email.',
+            },
+          },
+        },
         appointmentConfirmation: {
           description: 'The email sent to confirm an appointment',
           properties: {
